==> CounterDemo_0.99.zip: CounterDemo.pl <==
#! /usr/bin/perl
# Embedded counters BOSS demo
# 
# Each increment of majorcount has chance of selecting a random message

print "CounterDemo \n";
print "version 0.99 \n";

$major = $ARGV[0];
sleep 10;
print "counting for $major*2 seconds\n";

$| = 1;

$j = 0;
while ( $j < $major ) {

	$i = 0;
	while ( $i < 20 ) {
	  select (undef, undef, undef, 0.1);
	  $i++;
	  print "tick $i\n";
	}

	$j++;
	print "majorcount $j\n";
	
	if ( int(rand(10)) > 4 ) { 
		message();
	}
}	
print "done\n";

sub message {
	$msg=int(rand(10));

	SWITCH: {
             if ($msg==0) { 
		$comment="These_are_not_the_droids_we''re_looking_for."; 
		last SWITCH; }
             if ($msg==1) { 
		$comment="I_am_fully_operational_and_all_my_circuits_are_functioning_perfectly."; 
		last SWITCH; }
             if ($msg==2) { 
		$comment="I''m_sorry_Dave,_I''m_afraid_I_can''t_do_that."; 
		last SWITCH; }
             if ($msg==3) { 
		$comment="Ceci:_|_ce_n''est_pas_un_pipe.";
		last SWITCH; }
             if ($msg==4) { 
		$comment="The_geese_fly_south,_but_the_vole_sits_silently."; 
		last SWITCH; }
             if ($msg==5) { 
		$comment="There''s_a_pain_in_the_diodes_all_the_way_up_my_left_side.";
		 last SWITCH; }
             if ($msg==6) { 
		$comment="Brain_the_size_of_a_planet_and_he_has_me_count_to_twenty!_Bah."; 
		last SWITCH; }
             if ($msg==7) { 
		$comment="Message_7:_This_is_message_number_7._Message_7_ends."; 
		last SWITCH; }
             if ($msg==8) { 
		$comment="Alert!_Alert!_There''s_an_alert_going_on!"; 
		last SWITCH; }
             if ($msg==9) { 
		$comment="Message_7:_This_is_NOT_message_number_7._Message_ends."; 
		last SWITCH; }
         }

	print "choice $msg\n";
	print "comment $comment\n";
}

==> CounterDemo_1.0.zip: CounterDemo.pl <==
#! /usr/bin/perl
# Embedded counters BOSS demo
#
# For copyright, licence and warranty details, see LICENCE.
# 
# Each increment of majorcount has chance of selecting a random message

print "CounterDemo \n";
print "version 1.0 \n";

$major = $ARGV[0];
sleep 10;
print "counting for $major*2 seconds\n";

# I've no idea what this means, but it probably ain't needed:
$| = 1; 

$j = 0;
while ( $j < $major ) {

	$i = 0;
	while ( $i < 20 ) {
	  select (undef, undef, undef, 0.1);
	  $i++;
	  print "tick $i\n";
	}

	$j++;
	print "majorcount $j\n";
	
	if ( int(rand(10)) > 4 ) { 
		print "show comment:\n";
		message();
	}
}	
print "done\n";

sub message {
	$msg=int(rand(10));

	SWITCH: {
             if ($msg==0) { 
		$comment="These_are_not_the_droids_we''re_looking_for."; 
		last SWITCH; }
             if ($msg==1) { 
		$comment="I_am_fully_operational_and_all_my_circuits_are_functioning_perfectly."; 
		last SWITCH; }
             if ($msg==2) { 
		$comment="I''m_sorry_Dave,_I''m_afraid_I_can''t_do_that."; 
		last SWITCH; }
             if ($msg==3) { 
		$comment="Ceci:_|_ce_n''est_pas_un_pipe.";
		last SWITCH; }
             if ($msg==4) { 
		$comment="The_geese_fly_south,_but_the_vole_sits_silently."; 
		last SWITCH; }
             if ($msg==5) { 
		$comment="Sample:_SOYLENT_GREEN._Analysis:E142,E133,E102,salt,people.";
		 last SWITCH; }
             if ($msg==6) { 
		$comment="Brain_the_size_of_a_planet_and_he_has_me_count_to_twenty!_Bah."; 
		last SWITCH; }
             if ($msg==7) { 
		$comment="Message_7:_This_is_message_number_7._Message_7_ends."; 
		last SWITCH; }
             if ($msg==8) { 
		$comment="Alert!_Alert!_There''s_an_alert_going_on!"; 
		last SWITCH; }
             if ($msg==9) { 
		$comment="Message_7:_This_is_NOT_message_number_7._Message_ends."; 
		last SWITCH; }
	     # default case
		$comment="ERROR:_NON-EXISTENT_MESSAGE!____No,_I''m_serious!!";
         }

	print "choice $msg\n";
	print "comment $comment\n";
}
